#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-K5RY3VamqKM5ikmxRgb4Ae
key:                  warp-3.4.0-K5RY3VamqKM5ikmxRgb4Ae
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  674a5eb7b5a3bfa5618e6be307f4fcba
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-K5RY3VamqKM5ikmxRgb4Ae
depends:
    array-0.5.6.0 auto-update-0.1.6-E5aLWRUFo6vLtvWCrvKB9n
    base-4.18.2.1 bsb-http-chunked-0.0.0.4-LmikmZcexklLg24gPa4k3m
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-9SCmNmyRT1LDc1Bi3mXj6e
    containers-0.6.7 crypton-x509-1.7.7-F7bQyewUGUfKsEeyOtU2Ko
    ghc-prim-0.10.0 hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    http-date-0.0.11-IfqADiggNFP5V1ktDHaxd5
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    http2-5.1.4-FXUJnthI7jC83uHsu9d72u
    iproute-1.7.15-2jqavHpQBV91K8CvJZuO7b
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    recv-0.1.1-9msVSV0zeo7ABX2onmR8Ay
    simple-sendfile-0.2.32-I8bo15HxWfkAYZB1c7g1Y stm-2.5.1.0
    streaming-commons-0.2.3.1-IqBBzbpSoGCJEYKz1sdGdv text-2.0.2
    time-manager-0.0.1-FlSUlTCvRGL872tnwrfop unix-2.8.4.0
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    vault-0.3.2.0-CHFhjwtocqC1yyBgOAsYiw
    wai-3.2.5-H9aJt8uWBWE1hbliPLgYgy word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

